<?php
/**
 * Add Multiple User
 * 
 * @package    AddMultipleUser
 * @subpackage Add Multiple User Main function
/*  Copyright (c) 2019- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$addmultipleuser = new AddMultipleUser();

class AddMultipleUser {

	private $message;

	/* ==================================================
	 * Construct
	 * @since	1.00
	 */
	public function __construct() {

		add_action( 'show_password_fields', array($this, 'pay_form') );
		add_action( 'profile_update', array($this, 'update_user_profile'), 10, 2 );
		add_filter( 'simple_paypal_payment_charge', array($this, 'paypal_charge'), 10, 6 );
		add_filter( 'simple_stripe_payment_charge', array($this, 'stripe_charge'), 10, 7 );
		add_action( 'wp_dashboard_setup', array($this, 'pay_form_dashboard_widgets') );

		add_action( 'user_register', array($this, 'action_add_user'), 10, 1 );
		add_filter( 'wp_new_user_notification_email', array($this, 'regist_user_notify_mail'), 20, 3 );
		add_filter( 'wp_new_user_notification_email_admin', array($this, 'regist_user_notify_mail_admin'), 20, 3 );
		add_action( 'delete_user', array($this, 'action_delete_user'), 10, 1 );

		// original action hook
		add_action( 'amu_paid_add_user', array($this, 'paid'), 10, 1 );
		add_action( 'amu_paid_add_user_admin', array($this, 'paid_admin'), 10, 2 );

	}

	/* ==================================================
	 * Administrator Add User Hook
	 * @param	int		$userid		The user ID.
	 * @since	1.00
	 */
	public function action_add_user( $userid ){

		$amu_settings = get_option('addmultipleuser');
		$user = get_userdata($userid);
		$unm = $user->user_login;
		$key = get_password_reset_key($user);
		$useremail = $user->user_email;
		$role = implode( ', ', $user->roles );
		if ( $role === $amu_settings['def_role'] ) {
			$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
			if ( empty($amu_meta) ) {
				$prefix1 = substr($useremail, 0, 3);
				$prefix2 = date_i18n("ymdHi");
				$prefix = $prefix1.$prefix2;
				$amu_meta = array(
								'add' => 'def',
								'number' => $amu_settings['def_number'],
								'prefix' => $prefix
							);
				update_user_meta( $userid, 'amu_meta', $amu_meta );

				$this->message = $this->auto_insert_users($useremail, 1, $amu_meta['number'], $prefix, $amu_settings['add_role']);

			}
		}

	}

	/* ==================================================
	 * Notice mail when newly registering users
	 * @param	array	$wp_mail
	 * @param	object	$user
	 * @param	string	$blogname
	 * @since	1.00
	 */
	public function regist_user_notify_mail( $wp_mail, $user, $blogname ) {

		$amu_meta = get_user_meta( $user->ID, 'amu_meta', TRUE );
		if ( !empty($amu_meta) && array_key_exists( "number", $amu_meta ) ) {

			$subject = sprintf( __('[%1$s] login Username [%2$s]users', 'add-multiple-user'), $blogname, $amu_meta['number'] );
			$wp_mail['subject'] = $subject;

			$unm = $user->user_login;
			$key = get_password_reset_key($user);
			$message = __("Thank you for registering. The login information is as follows.", 'add-multiple-user')."\r\n\r\n";
			$message .= __('Login Address (URL)').':'.wp_login_url()."\r\n\r\n";
			$message .= sprintf( __('Username').'&'.__('Email').': %s', $unm )."\n";
			$message .= __('To reset your password, visit the following address:').': <'.network_site_url( "wp-login.php?action=rp&key=$key&login=" . rawurlencode( $unm ), 'login' ) . ">\r\n\r\n";
			$wp_mail['message'] = $message.$this->message;

		}

		return $wp_mail;

	}

	/* ==================================================
	 * Notice mail when newly registering users for admin
	 * @param	array	$wp_mail
	 * @param	object	$user
	 * @param	string	$blogname
	 * @since	1.00
	 */
	public function regist_user_notify_mail_admin( $wp_mail, $user, $blogname ) {

		$amu_meta = get_user_meta( $user->ID, 'amu_meta', TRUE );
		if ( !empty($amu_meta) && array_key_exists( "number", $amu_meta ) ) {

			$subject = sprintf( __('[%1$s] New User Registration [%2$s]users', 'add-multiple-user'), $blogname, $amu_meta['number'] );
			$wp_mail['subject'] = $subject;

			$unm = $user->user_login;
			$message = sprintf( __("New user registration on your site %s:"), $blogname )."\r\n\r\n";
			$message .= sprintf( __('Username').'&'.__('Email').': %s', $unm )."\r\n\r\n";

			$amu_settings = get_option('addmultipleuser');
			if ( $amu_meta['add'] === 'def' ) {
				$min = 1;
				$max = $amu_meta['number'];
			} else { // paid
				$min = $amu_settings['def_number'] + 1;
				$max = $amu_meta['number'];
			}
			$message .= __('Multiple users added as follows.', 'add-multiple-user')."\r\n\r\n";
			for ( $i = $min; $i <= $max; $i++ ) {
				$message .= sprintf( __('Username').': %s', $amu_meta['prefix'].sprintf( '%02d', $i ) )."\n";
			}

			$wp_mail['message'] = $message;

		}

		return $wp_mail;

	}

	/* ==================================================
	 * Create multiple user
	 * @param	string	$e_mail
	 * @param	int		$number_min
	 * @param	int		$number_count
	 * @param	string	$prefix
	 * @param	string	$add_role
	 * @return	string	$messgae
	 * @since	1.00
	 */
	private function auto_insert_users($e_mail, $number_min, $number_count, $prefix, $add_role) {

		$message = __('Multiple users added as follows.', 'add-multiple-user')."\r\n\r\n";

		$user_ids = array();
		for ( $i = $number_min; $i <= $number_count; $i++ ) {
			$unm = $prefix.sprintf( '%02d', $i );
			$pswd = wp_generate_password(8, FALSE, FALSE);
			$userdata = array(
				'user_login'	=>	$unm,
				'user_pass'		=>	$pswd,
				'role'			=>	$add_role
			);
			$user_ids[] = wp_insert_user( $userdata );
		}

		foreach ( $user_ids as $userid) {
			global $wpdb;
			$result = $wpdb->query($wpdb->prepare("UPDATE $wpdb->users SET user_email = %s WHERE ID = %d",$e_mail,$userid));
			$user_info = get_userdata($userid);
			$unm = $user_info->user_login;
			$key = get_password_reset_key($user_info);
			$message .= sprintf( __('Username').': %s', $unm )."\n";
			$message .= __('To reset your password, visit the following address:').': <'.network_site_url( "wp-login.php?action=rp&key=$key&login=" . rawurlencode( $unm ), 'login' ) . ">\r\n\r\n";
		}

		return $message;

	}

	/* ==================================================
	 * Delete User Hook
	 * @param	int		$userid		The user ID.
	 * @since	1.00
	 */
	public function action_delete_user( $userid ) {

		$amu_settings = get_option('addmultipleuser');
		$user = get_userdata($userid);
		$useremail = $user->user_email;
		$role = implode( ', ', $user->roles );
		$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
		if ( !empty($amu_meta) ) {
			if ( array_key_exists( "prefix", $amu_meta ) && array_key_exists( "number", $amu_meta ) ) {

				$subject = sprintf(__("[%s] Delete Acount", 'add-multiple-user'), get_option('blogname') );
				$message = __("The created account has been deleted. Thank you for using.", 'add-multiple-user')."\r\n\r\n";
				$message_admin = sprintf(__("The created account[%s] has been deleted.", 'add-multiple-user'), $useremail)."\r\n\r\n";
				wp_mail( $useremail, $subject, $message);
				@wp_mail(get_option('admin_email'), $subject, $message_admin);

				// Delete users
				$user_prefix = $amu_meta['prefix'];
				for ( $i = 1; $i <= $amu_meta['number']; $i++ ) {
					$unm = $user_prefix.sprintf( '%02d', $i );
					if ( username_exists($unm) ) {
						wp_delete_user(username_exists($unm));
					}
				}
			}
		}

	}

	/* ==================================================
	 * Pay form
	 * @since	1.00
	 */
	public function pay_form( $bool ) {

		global $profileuser;
		if ( preg_match( '/^(profile\.php|user-edit\.php)/', basename( $_SERVER['REQUEST_URI'] ) ) ) {
			if( current_user_can('administrator') ) {
				if ( isset($_GET['user_id']) && $_GET['user_id'] ) {
					$userid = intval($_GET['user_id']);
					$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
					if ( !empty($amu_meta) && array_key_exists( "add", $amu_meta ) ) {
						?>
						<tr>
						<th><label for="description"><?php echo 'Add Multiple User '.__('Status'); ?></label></th>
						<td>
						<?php
						if ( $amu_meta['add'] === 'paid' ) {
							?>
							<p class="description"><?php echo __('Paid', 'add-multiple-user').' '.('User'); ?></p>
							<?php
						} else {
							?>
							<p class="description"><?php echo __('Default').' '.('User'); ?></p>
							<input type="checkbox" name="amu_paid_admin" value="1" />
							<?php
							echo __('Change to paid user.', 'add-multiple-user');
						}
						?>
						</td>
						</tr>
						<?php
					}
				}
			} else {
				$user = wp_get_current_user();
				$userid = $user->ID;
				$useremail = $user->user_email;
				$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
				if ( !empty($amu_meta) && array_key_exists( "add", $amu_meta ) ) {
					?>
					<tr>
					<th><label for="description"><?php echo 'Add Multiple User '.__('Status'); ?></label></th>
					<td>
					<?php
					if ( $amu_meta['add'] === 'paid' ) {
						?>
						<p class="description"><?php echo __('Paid', 'add-multiple-user').' '.('User'); ?></p>
						<?php
					} else {
						?>
						<span class="tempregist"><p class="description"><?php echo __('Default').' '.('User'); ?></p></span>
						<?php
						if( class_exists('SimplePayPalPayment') ) echo do_shortcode('[simplepaypalpayment size="medium" email="'.$useremail.'" after="<h3>'.__('Paid', 'add-multiple-user').' '.('User').'</h3>" remove=".tempregist" remove2="#SPPcustomButton" payname="add-multiple-user"]');
						if( class_exists('SimpleStripePayment') ) echo do_shortcode('[simplestripepayment email="'.$useremail.'" after="<h3>'.__('Paid', 'add-multiple-user').' '.('User').'</h3>" remove=".tempregist" remove2="#simple_paypal_payment_paypal-button" payname="add-multiple-user"]');
					}
					?>
					</td>
					</tr>
					<?php
				}
			}
		}

		return $bool;

	}

	/* ==================================================
	 * Pay form for Dashboard
	 * @since	1.00
	 */
	public function pay_form_dashboard_widgets() {

		$user = wp_get_current_user();
		$userid = $user->ID;
		$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
		if ( !empty($amu_meta) && array_key_exists( "add", $amu_meta ) ) {
			global $wp_meta_boxes;
			wp_add_dashboard_widget( 'custom_help_widget', 'Add Multiple User '.__('Status'), array($this, 'dashboard_text') );
		}

	}

	/* ==================================================
	 * Dashboard text
	 * @since	1.00
	 */
	public function dashboard_text() {

		if ( preg_match( '/^(index\.php)/', basename( $_SERVER['REQUEST_URI'] ) ) ) {
			if( current_user_can('administrator') ) {
				if ( isset($_GET['user_id']) && $_GET['user_id'] ) {
					$userid = intval($_GET['user_id']);
					$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
					if ( !empty($amu_meta) && array_key_exists( "add", $amu_meta ) ) {
						if ( $amu_meta['add'] === 'paid' ) {
							?>
							<h3><strong><?php echo __('Default').' '.('User'); ?></strong></h3>
							<?php
						} else {
							?>
							<h3><strong><?php echo __('Paid', 'add-multiple-user').' '.('User'); ?></strong></h3>
							<?php
						}
					}
				}
			} else {
				$user = wp_get_current_user();
				$userid = $user->ID;
				$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
				$useremail = $user->user_email;
				if ( !empty($amu_meta) && array_key_exists( "add", $amu_meta ) ) {
					if ( $amu_meta['add'] === 'paid' ) {
						?>
						<h3><strong><?php echo __('Paid', 'add-multiple-user').' '.('User'); ?></strong></h3>
						<?php
					} else {
						?>
						<span class="tempregist"><h3><strong><?php echo __('Default').' '.('User'); ?></strong></h3></span>
						<?php
						if( class_exists('SimplePayPalPayment') ) echo do_shortcode('[simplepaypalpayment size="medium" email="'.$useremail.'" after="<h3>'.__('Paid', 'add-multiple-user').' '.('User').'</h3>" remove=".tempregist" remove2="#SPPcustomButton" payname="add-multiple-user"]');
						if( class_exists('SimpleStripePayment') ) echo do_shortcode('[simplestripepayment email="'.$useremail.'" after="<h3>'.__('Paid', 'add-multiple-user').' '.('User').'</h3>" remove=".tempregist" remove2="#simple_paypal_payment_paypal-button" payname="add-multiple-user"]');
					}
				}
			}
		}

	}

	/* ==================================================
	 * PayPal Charge
	 * @since	1.00
	 */
	public function paypal_charge( $data, $payment_data, $email, $amount, $currency, $payname ) {
		do_action( 'amu_paid_add_user', $payname );
	}

	/* ==================================================
	 * Stripe Charge
	 * @since	1.00
	 */
	public function stripe_charge( $token, $email, $amount, $currency, $name, $description, $payname ) {
		do_action( 'amu_paid_add_user', $payname );
	}

	/* ==================================================
	 * Paid
	 * @since	1.00
	 */
	public function paid($payname) {

		if ( is_admin() && $payname == 'add-multiple-user' ) {
			$amu_settings = get_option('addmultipleuser');
			$user = wp_get_current_user();
			$unm = $user->user_login;
			$key = get_password_reset_key($user);
			$userid = $user->ID;
			$useremail = $user->user_email;
			$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
			if ( !empty($amu_meta) && array_key_exists( "add", $amu_meta ) ) {
				if ( $amu_meta['add'] === 'def' ) {
					$def_number = $amu_meta['number'];
					$amu_meta['add'] = 'paid';
					$amu_meta['number'] = $amu_settings['paid_number'];
					update_user_meta( $userid, 'amu_meta', $amu_meta );

					// for user
					$subject = sprintf( __('[%1$s] login Username [%2$s]users', 'add-multiple-user'), get_option('blogname'), $amu_meta['number'] );
					$message = $this->auto_insert_users($useremail, $def_number + 1, $amu_meta['number'], $amu_meta['prefix'], $amu_settings['add_role']);
					// for admin
					$subject_admin = sprintf( __('[%1$s] New User Registration [%2$s]users', 'add-multiple-user'), get_option('blogname'), $amu_meta['number'] );
					$unm = $user->user_login;
					$message_admin = sprintf( __("New user registration on your site %s:"), get_option('blogname') )."\r\n\r\n";
					$message_admin .= sprintf( __('Username').'&'.__('Email').': %s', $unm )."\r\n\r\n";
					$min = $def_number + 1;
					$max = $amu_meta['number'];
					$message_admin .= __('Multiple users added as follows.', 'add-multiple-user')."\r\n\r\n";
					for ( $i = $min; $i <= $max; $i++ ) {
						$message_admin .= sprintf( __('Username').': %s', $amu_meta['prefix'].sprintf( '%02d', $i ) )."\n";
					}

					wp_mail( $useremail, $subject, $message);
					@wp_mail(get_option('admin_email'), $subject_admin, $message_admin);

				}
			}
		}

	}

	/* ==================================================
	 * Paid
	 * @since	1.00
	 */
	public function paid_admin($payname, $userid) {

		if ( is_admin() && $payname == 'add-multiple-user' ) {
			$amu_settings = get_option('addmultipleuser');
			$user = get_userdata($userid);
			$unm = $user->user_login;
			$key = get_password_reset_key($user);
			$useremail = $user->user_email;
			$amu_meta = get_user_meta( $userid, 'amu_meta', TRUE );
			if ( !empty($amu_meta) && array_key_exists( "add", $amu_meta ) ) {
				if ( $amu_meta['add'] === 'def' ) {
					$def_number = $amu_meta['number'];
					$amu_meta['add'] = 'paid';
					$amu_meta['number'] = $amu_settings['paid_number'];
					update_user_meta( $userid, 'amu_meta', $amu_meta );

					// for user
					$subject = sprintf( __('[%1$s] login Username [%2$s]users', 'add-multiple-user'), get_option('blogname'), $amu_meta['number'] );
					$message = $this->auto_insert_users($useremail, $def_number + 1, $amu_meta['number'], $amu_meta['prefix'], $amu_settings['add_role']);
					// for admin
					$subject_admin = sprintf( __('[%1$s] New User Registration [%2$s]users', 'add-multiple-user'), get_option('blogname'), $amu_meta['number'] );
					$unm = $user->user_login;
					$message_admin = sprintf( __("New user registration on your site %s:"), get_option('blogname') )."\r\n\r\n";
					$message_admin .= sprintf( __('Username').'&'.__('Email').': %s', $unm )."\r\n\r\n";
					$min = $def_number + 1;
					$max = $amu_meta['number'];
					$message_admin .= __('Multiple users added as follows.', 'add-multiple-user')."\r\n\r\n";
					for ( $i = $min; $i <= $max; $i++ ) {
						$message_admin .= sprintf( __('Username').': %s', $amu_meta['prefix'].sprintf( '%02d', $i ) )."\n";
					}

					wp_mail( $useremail, $subject, $message);
					@wp_mail(get_option('admin_email'), $subject_admin, $message_admin);

				}
			}
		}

	}


	public function update_user_profile( $userid, $old_user_data ) {

		if ( isset( $_POST['amu_paid_admin'] ) && $old_user_data->amu_paid_admin != $_POST['amu_paid_admin'] ) {
			$amu_paid_admin = intval( $_POST['amu_paid_admin'] );
			do_action( 'amu_paid_add_user_admin', 'add-multiple-user', $userid );
		}

	}

}

?>
