<?php
/**
 * Add Multiple User
 * 
 * @package    Add Multiple User
 * @subpackage AddMultipleUserAdmin Management screen
    Copyright (c) 2019- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$addmultipleuseradmin = new AddMultipleUserAdmin();
add_action( 'admin_notices', array($addmultipleuseradmin, 'notices') );

class AddMultipleUserAdmin {

	/* ==================================================
	 * Construct
	 * @since	1.00
	 */
	public function __construct() {

		add_action( 'admin_menu', array($this, 'plugin_menu'));
		add_action( 'admin_enqueue_scripts', array($this, 'load_custom_wp_admin_style') );
		add_filter( 'plugin_action_links', array($this, 'settings_link'), 10, 2 );

	}

	/* ==================================================
	 * Add a "Settings" link to the plugins page
	 * @since	1.00
	 */
	public function settings_link( $links, $file ) {
		static $this_plugin;
		if ( empty($this_plugin) ) {
			$this_plugin = 'add-multiple-user/addmultipleuser.php';
		}
		if ( $file == $this_plugin ) {
			$links[] = '<a href="'.admin_url('options-general.php?page=addmultipleuser').'">'.__( 'Settings').'</a>';
		}
			return $links;
	}

	/* ==================================================
	 * Settings page
	 * @since	1.00
	 */
	public function plugin_menu() {
		add_options_page( 'Add Multiple User Options', 'Add Multiple User', 'manage_options', 'addmultipleuser', array($this, 'plugin_options') );
	}

	/* ==================================================
	 * Add Css and Script
	 * @since	1.00
	 */
	public function load_custom_wp_admin_style() {
		if ($this->is_my_plugin_screen()) {
			wp_enqueue_style( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ).'css/responsive-tabs.css' );
			wp_enqueue_style( 'jquery-responsiveTabs-style', plugin_dir_url( __DIR__ ).'css/style.css' );
			wp_enqueue_script('jquery');
			wp_enqueue_script( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ).'js/jquery.responsiveTabs.min.js' );
			wp_enqueue_script( 'addmultipleuser-admin-js', plugin_dir_url( __DIR__ ).'js/jquery.addmultipleuser.admin.js', array('jquery') );
		}
	}

	/* ==================================================
	 * For only admin style
	 * @since	1.00
	 */
	private function is_my_plugin_screen() {
		$screen = get_current_screen();
		if (is_object($screen) && $screen->id == 'settings_page_addmultipleuser') {
			return TRUE;
		} else {
			return FALSE;
		}
	}

	/* ==================================================
	 * Settings page
	 * @since	1.00
	 */
	public function plugin_options() {

		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}

		if ( isset($_POST['Manageset']) && $_POST['Manageset'] ) {
			if ( check_admin_referer('amu_set', 'addmultipleuser_set') ) {
				$this->options_updated();
			}
		}

		$scriptname = admin_url('options-general.php?page=addmultipleuser');
		$amu_settings = get_option('addmultipleuser');

		?>

		<div class="wrap">
		<h2>Add Multiple User</h2>

	<div id="addmultipleuser-admin-tabs">
	  <ul>
		<li><a href="#addmultipleuser-admin-tabs-1">Add Multiple User&nbsp<?php _e('Settings'); ?></a></li>
		<li><a href="#addmultipleuser-admin-tabs-2"><?php _e('Hook', 'add-multiple-user'); ?></a></li>
		<li><a href="#addmultipleuser-admin-tabs-3"><?php _e('Donate to this plugin &#187;'); ?></a></li>
	  </ul>

	  <div id="addmultipleuser-admin-tabs-1">
		<div class="wrap">
			<h2>Add Multiple User <?php _e('Settings'); ?></h2>	

			<form method="post" action="<?php echo $scriptname; ?>">
			<?php wp_nonce_field('amu_set', 'addmultipleuser_set'); ?>

			<div style="margin: 5px; padding: 5px;">
			<h3><?php echo 'WordPress '.__('Settings'); ?></h3>
			<div style="display: block;padding:5px 5px">
			<?php _e('Membership'); ?> : 
			<input name="users_can_register" type="checkbox" value="1" <?php checked( '1', get_option('users_can_register') ); ?> />
			<?php _e('Anyone can register'); ?>
			</div>
			<div style="display: block;padding:5px 5px">
			<?php _e('New User Default Role'); ?> : 
			<select name="default_role">
			<?php wp_dropdown_roles( get_option('default_role') ); ?>
			</select>
			</div>
			</div>

			<div style="margin: 5px; padding: 5px;">
			<h3><?php _e('User roles and additional number', 'add-multiple-user'); ?></h3>
			<div style="display: block;padding:5px 5px">
			<table border=1 cellspacing="0" cellpadding="5" bordercolor="#000000" style="border-collapse: collapse">
			<tr>
			<td rowspan="2" align="center"><?php _e('User'); ?></td>
			<td rowspan="2" align="center"><?php _e('Role'); ?></td>
			<td colspan="2" align="center"><?php _e('Additional number', 'add-multiple-user'); ?></td>
			</tr>
			<tr>
			<td align="center"><?php _e('Default'); ?></td>
			<td align="center"><?php _e('Paid', 'add-multiple-user'); ?></td>
			</tr>
			<tr>
			<td align="right"><?php _e('Parent user', 'add-multiple-user'); ?></td>
			<td align="center">
			<select name="def_role">
			<?php wp_dropdown_roles( $amu_settings['def_role'] ); ?>
			</select>
			</td>
			<td colspan="2"></td>
			</tr>
			<tr>
			<td align="right"><?php _e('Child users', 'add-multiple-user'); ?></td>
			<td align="center">
			<select name="add_role">
			<?php wp_dropdown_roles( $amu_settings['add_role'] ); ?>
			</select>
			</td>
			<td align="center">
			<input type="number" name="def_number" min="1" max="98" style="width: 60px;" value="<?php echo intval($amu_settings['def_number']); ?>"> <?php _e('1 to 98', 'add-multiple-user'); ?>
			</td>
			<td align="center">
			<input type="number" name="paid_number" min="2" max="99" style="width: 60px;" value="<?php echo intval($amu_settings['paid_number']); ?>"> <?php _e('2 to 99', 'add-multiple-user'); ?>
			</td>
			</tr>
			</table>
			</div>
			</div>

			<?php submit_button( __('Save Changes'), 'large', 'Manageset', FALSE ); ?>

			</form>

		</div>
	  </div>

	  <div id="addmultipleuser-admin-tabs-2">
		<div class="wrap">
			<h3><?php _e('The following action hook are provided.', 'add-multiple-user'); ?></h3>
			<h4>amu_paid_add_user</h4>
			<div><?php _e("Process of user's payment and send email to user.", 'add-multiple-user'); ?></div>
			<h4>amu_paid_add_user_admin</h4>
			<div><?php _e("Process of user's payment and send email to admin.", 'add-multiple-user'); ?></div>
			<p>
			<div><strong><?php _e('Sample code', 'add-multiple-user'); ?></strong></div>
<textarea rows="6" cols="80" readonly>
// Payname : add-multiple-user
do_action( 'amu_paid_add_user', 'add-multiple-user' );

// Payname : add-multiple-user , User ID : $userid
do_action( 'amu_paid_add_user_admin', 'add-multiple-user', $userid );
</textarea>
		</div>
	  </div>

	  <div id="addmultipleuser-admin-tabs-3">
		<div class="wrap">
		<?php $this->credit(); ?>
		</div>
	  </div>

	</div>

		</div>
		<?php
	}

	/* ==================================================
	 * Credit
	 */
	private function credit() {

		$plugin_name = NULL;
		$plugin_ver_num = NULL;
		$plugin_path = plugin_dir_path( __DIR__ );
		$plugin_dir = untrailingslashit($plugin_path);
		$slugs = explode('/', $plugin_dir);
		$slug = end($slugs);
		$files = scandir($plugin_dir);
		foreach ($files as $file) {
			if($file == '.' || $file == '..' || is_dir($plugin_path.$file)){
				continue;
			} else {
				$exts = explode('.', $file);
				$ext = strtolower(end($exts));
				if ( $ext === 'php' ) {
					$plugin_datas = get_file_data( $plugin_path.$file, array('name'=>'Plugin Name', 'version' => 'Version') );
					if ( array_key_exists( "name", $plugin_datas ) && !empty($plugin_datas['name']) && array_key_exists( "version", $plugin_datas ) && !empty($plugin_datas['version']) ) {
						$plugin_name = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __('Version:').' '.$plugin_ver_num;
		$faq = __('https://wordpress.org/plugins/'.$slug.'/faq', $slug);
		$support = 'https://wordpress.org/support/plugin/'.$slug;
		$review = 'https://wordpress.org/support/view/plugin-reviews/'.$slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/'.$slug;
		$facebook = 'https://www.facebook.com/katsushikawamori/';
		$twitter = 'https://twitter.com/dodesyo312';
		$youtube = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate = __('https://shop.riverforest-wp.info/donate/', $slug);

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo $plugin_version; ?> | 
		<a style="text-decoration: none;" href="<?php echo $faq; ?>" target="_blank"><?php _e('FAQ'); ?></a> | <a style="text-decoration: none;" href="<?php echo $support; ?>" target="_blank"><?php _e('Support Forums'); ?></a> | <a style="text-decoration: none;" href="<?php echo $review; ?>" target="_blank"><?php _e('Reviews', 'add-multiple-user'); ?></a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo $translate; ?>" target="_blank"><?php echo sprintf(__('Translations for %s'), $plugin_name); ?></a> | <a style="text-decoration: none;" href="<?php echo $facebook; ?>" target="_blank"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo $twitter; ?>" target="_blank"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo $youtube; ?>" target="_blank"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php _e('Please make a donation if you like my work or would like to further the development of this plugin.', $slug); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo $donate; ?>')"><?php _e('Donate to this plugin &#187;'); ?></button>
		</div>

		<?php

	}

	/* ==================================================
	 * Update wp_options table.
	 * @param	none
	 * @since	1.00
	 */
	private function options_updated(){

		if ( !empty($_POST['Manageset']) ) {
			if ( !empty($_POST['users_can_register']) ) {
				update_option('users_can_register', TRUE);
			} else {
				update_option('users_can_register', FALSE);
			}
			if ( !empty($_POST['default_role']) ) {
				update_option('default_role', sanitize_text_field($_POST['default_role']));
			}
			if ( intval($_POST['def_number']) > intval($_POST['paid_number']) ) {
				echo '<div class="notice notice-error is-dismissible"><ul><li>'.sprintf( __('%1$s must be a number greater than %2$s.', 'add-multiple-user'), __('Paid additional number', 'add-multiple-user'), __('Default additional number', 'add-multiple-user') ).'</li></ul></div>';
				return;
			}
			$amu_settings = get_option('addmultipleuser');
			if ( !empty($_POST['def_role']) ) {
				$amu_settings['def_role'] = sanitize_text_field($_POST['def_role']);
			}
			if ( !empty($_POST['add_role']) ) {
				$amu_settings['add_role'] = sanitize_text_field($_POST['add_role']);
			}
			if ( !empty($_POST['def_number']) ) {
				$amu_settings['def_number'] = intval($_POST['def_number']);
			}
			if ( !empty($_POST['paid_number']) ) {
				$amu_settings['paid_number'] = intval($_POST['paid_number']);
			}
			update_option( 'addmultipleuser', $amu_settings );
			echo '<div class="notice notice-success is-dismissible"><ul><li>'.__('Settings').' --> '.__('Settings saved.').'</li></ul></div>';
		}

	}

	/* ==================================================
	 * @param	none
	 * @return	string
	 * @since	1.00
	 */
	public function notices() {

		if ($this->is_my_plugin_screen()) {
			if ( is_multisite() ) {
				$umor_install_url = network_admin_url('plugin-install.php?tab=plugin-information&plugin=user-mail-only-register');
				$spp_install_url = network_admin_url('plugin-install.php?tab=plugin-information&plugin=simple-paypal-payment');
				$ssp_install_url = network_admin_url('plugin-install.php?tab=plugin-information&plugin=simple-stripe-payment');
			} else {
				$umor_install_url = admin_url('plugin-install.php?tab=plugin-information&plugin=user-mail-only-register');
				$spp_install_url = admin_url('plugin-install.php?tab=plugin-information&plugin=simple-paypal-payment');
				$ssp_install_url = admin_url('plugin-install.php?tab=plugin-information&plugin=simple-stripe-payment');
			}
			$umor_install_html = '<a href="'.$umor_install_url.'" target="_blank" style="text-decoration: none; word-break: break-all;">User Mail Only Register</a>';
			$spp_install_html = '<a href="'.$spp_install_url.'" target="_blank" style="text-decoration: none; word-break: break-all;">Simple PayPal Payment</a>';
			$ssp_install_html = '<a href="'.$ssp_install_url.'" target="_blank" style="text-decoration: none; word-break: break-all;">Simple Stripe Payment</a>';
			if ( !class_exists('UserMailOnlyRegister') ) {
				echo '<div class="notice notice-warning is-dismissible"><ul><li>'.sprintf(__('If you wish to make the registration form mail only, Please use the %1$s.','add-multiple-user'), $umor_install_html).'</li></ul></div>';
			}
			if ( !class_exists('SimplePayPalPayment') ) {
				echo '<div class="notice notice-warning is-dismissible"><ul><li>'.sprintf(__('If you want registered users to charge with %1$s, Please use the %2$s.','add-multiple-user'), 'PayPal', $spp_install_html).'</li></ul></div>';
			}
			if ( !class_exists('SimpleStripePayment') ) {
				echo '<div class="notice notice-warning is-dismissible"><ul><li>'.sprintf(__('If you want registered users to charge with %1$s, Please use the %2$s.','add-multiple-user'), 'Stripe', $ssp_install_html).'</li></ul></div>';
			}
		}

	}

}

?>